import type { PlaywrightTestConfig } from '@playwright/test';

/**
 * If this was an app level config, we might import each fixture from the mfs we're using to create a union
 */
import type { TestFixture as LoginFixture } from './test/e2e';

type Fixtures = LoginFixture & {}; // < and several others if this was app level

const config: PlaywrightTestConfig<Fixtures> = {
  testMatch: '**/*.e2e.ts',
  globalSetup: '@genesislcap/foundation-testing/playwright', // returns teardown
  /**
   * We might create a discreet project per mf, or an entire config per mf, will know soon enough...
   */
  projects: [
    {
      name: 'Chrome Stable',
      use: {
        browserName: 'chromium',
        channel: 'chrome',
        ignoreHTTPSErrors: true,
        /**
         * We should be able to use these 'use' blocks at the App level to provide config data to our micro frontends.
         * This might include what backend to run against, what username password combo to use etc.
         *
         * config: AppLevelPkgConfig;
         */
        // config: {
        //   API_HOST: 'wss://dev-foundation1/gwf/',
        //   DEFAULT_USER: 'Derek',
        //   DEFAULT_PASSWORD: 'Paul',
        //   PORT: 5030,
        // },
      },
    },
  ],
  webServer: {
    command: 'npm run dev:no-open',
    url: 'http://localhost:5030/',
    timeout: 120000,
    reuseExistingServer: !process.env.CI,
  },
  use: {
    baseURL: 'http://localhost:5030/',
  },
  // reporter: [['html', { open: 'never' }]],
};

export default config;
